<?php


use think\migration\Migrator;
use think\migration\db\Column;
use Phinx\Db\Adapter\MysqlAdapter;

class WorkRecord extends Migrator
{
    /**
     * Change Method.
     *
     * Write your reversible migrations using this method.
     *
     * More information on writing migrations is available here:
     * http://docs.phinx.org/en/latest/migrations.html#the-abstractmigration-class
     *
     * The following commands can be used in this method and Phinx will
     * automatically reverse them when rolling back:
     *
     *    createTable
     *    renameTable
     *    addColumn
     *    renameColumn
     *    addIndex
     *    addForeignKey
     *
     * Remember to call "create()" or "update()" and NOT "save()" when working
     * with the Table class.
     */
    public function change()
    {
        $table = $this->table('work_record', ['engine' => 'InnoDB', 'collation' => 'utf8mb4_general_ci', 'comment' => '', 'id' => 'id', 'signed' => true, 'primary_key' => ['id']]);
        $table->addColumn('wind_number', 'string', ['limit' => 50, 'null' => true, 'signed' => true, 'comment' => '风场编号',])
            ->addColumn('fan_number', 'string', ['limit' => 50, 'null' => true, 'signed' => true, 'comment' => '风机编号',])
            ->addColumn('fan_model', 'string', ['limit' => 50, 'null' => true, 'signed' => true, 'comment' => '风机模型',])
            ->addColumn('parts', 'string', ['limit' => 50, 'null' => true, 'signed' => true, 'comment' => '部件',])
            ->addColumn('boit_type', 'string', ['limit' => 50, 'null' => true, 'signed' => true, 'comment' => '螺栓型号',])
            ->addColumn('bolt_number', 'string', ['limit' => 50, 'null' => true, 'signed' => true, 'comment' => '螺栓编号',])
            ->addColumn('boit_total', 'integer', ['limit' => MysqlAdapter::INT_REGULAR, 'null' => true, 'signed' => true, 'comment' => '螺栓总数',])
            ->addColumn('wrench_number', 'string', ['limit' => 50, 'null' => true, 'signed' => true, 'comment' => '扳手编号',])
            ->addColumn('set_torque', 'string', ['limit' => 50, 'null' => true, 'signed' => true, 'comment' => '设定的扭矩1',])
            ->addColumn('fastening_torque', 'string', ['limit' => 50, 'null' => true, 'signed' => true, 'comment' => '紧固扭矩1',])
            ->addColumn('set_torque1', 'string', ['limit' => 50, 'null' => true, 'signed' => true, 'comment' => '设定的扭矩2',])
            ->addColumn('fastening_torque1', 'string', ['limit' => 50, 'null' => true, 'signed' => true, 'comment' => '紧固扭矩2',])
            ->addColumn('fastening_status', 'integer', ['limit' => MysqlAdapter::INT_REGULAR, 'null' => true, 'signed' => true, 'comment' => '1 紧固正常，2紧固异常',])
            ->addColumn('fastening_time', 'string', ['limit' => 20, 'null' => true, 'signed' => true, 'comment' => '紧固时间',])
            ->addColumn('move_angle', 'string', ['limit' => 10, 'null' => true, 'signed' => true, 'comment' => '搬动角度',])
            ->addColumn('imei', 'string', ['limit' => 50, 'null' => true, 'signed' => true, 'comment' => '网关imei',])
            ->addColumn('tyep', 'integer', ['limit' => MysqlAdapter::INT_REGULAR, 'null' => true, 'signed' => true, 'comment' => '1 紧固模式，2维护模式',])
            ->addColumn('creator_id', 'integer', ['limit' => MysqlAdapter::INT_REGULAR, 'null' => false, 'default' => 0, 'signed' => false, 'comment' => '创建人ID',])
            ->addColumn('created_at', 'integer', ['limit' => MysqlAdapter::INT_REGULAR, 'null' => false, 'default' => 0, 'signed' => false, 'comment' => '创建时间',])
            ->addColumn('updated_at', 'integer', ['limit' => MysqlAdapter::INT_REGULAR, 'null' => false, 'default' => 0, 'signed' => false, 'comment' => '更新时间',])
            ->addColumn('deleted_at', 'integer', ['limit' => MysqlAdapter::INT_REGULAR, 'null' => false, 'default' => 0, 'signed' => false, 'comment' => '软删除',])
            ->create();
    }
}
