<?php

namespace catchAdmin\worklocation\model;

use catchAdmin\api\Listen;
use catchAdmin\hydraulic\model\DeviceMold as ModelDeviceMold;
use catcher\base\CatchModel as Model;
use catchAdmin\permissions\model\DataRangScopeTrait;
use catchAdmin\wind\model\Fan;
use catchAdmin\wind\model\Wind;
use DeviceMold;
use think\facade\Db;

class WorkRecord extends Model
{
    use Listen;
    use DataRangScopeTrait;
    // 表名
    public $name = 'work_record';
    // 数据库字段映射
    public $field = array(
        'id',
        // 风场编号
        'wind_number',
        // 风机编号
        'fan_number',
        //风机模型
        'fan_model',
        // 部件
        'parts',
        // 螺栓型号
        'boit_type',
        // 螺栓编号
        'bolt_number',
        // 螺栓总数
        'boit_total',
        // 扳手编号
        'wrench_number',
        // 设定的扭矩1
        'set_torque',
        // 紧固扭矩1
        'fastening_torque',
        // 设定的扭矩2
        'set_torque1',
        // 紧固扭矩2
        'fastening_torque1',
        // 1 紧固正常，2紧固异常
        'fastening_status',
        // 紧固时间
        'fastening_time',
        // 搬动角度
        'move_angle',
        // 网关imei
        'imei',
        // 1 紧固模式，2维护模式
        'tyep',
        // 创建人ID
        'creator_id',
        // 创建时间
        'created_at',
        // 更新时间
        'updated_at',
        // 软删除
        'deleted_at',
    );
    public function getList()
    {
        return $this->dataRange()
            ->catchSearch()
            ->append(['department_name', 'wind_name', 'work_local_name', 'parts_name', 'boit_type_name', 'work_name'])
            ->field('*')
            ->catchOrder()
            ->creator()
            ->paginate();
    }
    //获取部门名称
    public function getDepartmentNameAttr()
    {
        $dep_id = Db::name('wind')->where('number', $this->wind_number)->value('department_id');
        $name = Db::name('departments')->where('id', $dep_id)->where('status', 1)->value('department_name');
        return $name;
    }

    /**
     * 获取风场名称
     *
     * @return void
     */
    public function getWindNameAttr()
    {
        $wind_number = $this->wind_number;
        $wind_name =  Db::name('wind')->where('number', $wind_number)->value('name');
        return $wind_name;
    }
    //获取操作人员
    public function getWorkNameAttr()
    {
        $user_id = $this->creator_id;
        $name =  Db::name("users")->where('id', $user_id)->value('realname');
        return $name;
    }

    /**
     * 获取部件名称
     *
     * @return void
     */
    public function getPartsNameAttr()
    {
        $parts = $this->parts;
        $value = $this->get_dict_data(1, $parts);
        return $value;
    }
    //获取工作位置型号
    public function getWorkLocalNameAttr()
    {
        $code = $this->work_local;
        $value = $this->get_dict_data(2, $code);
        return $value;
    }
    /**
     * 螺栓型号
     *
     * @return void
     */
    public function getBoitTypeNameAttr()
    {
        $code = $this->boit_type;
        $value = $this->get_dict_data(4, $code);
        return $value;
    }

    /**
     * 
     * @param [type] $type 类型
     * @param [type] $value 唯一value
     * @return void
     */
    public function get_dict_data($type, $value)
    {
        $where[] = ['device_type', "=", $type];
        $where[] = ['value', '=', $value];
        $name = Db::name('maintenance_mapper')->where($where)->value('name');
        return $name;
    }
    /**
     * 监听转换
     */
    public function addContent(&$obj)
    {
        $data = null;
        $content = null;
        $data = [
            'id' => $obj->wind_number . $obj->fan_number . $obj->fan_model . $obj->parts . $obj->work_local,
            'wnum' => $obj->wind_number,
            'fnum' => $obj->fan_number,
            'fmodel'  => ModelDeviceMold::where('device_type', 4)->where('id', $this->fan_model)->value('name'),
            'parts' => $this->get_dict_data(1, $obj->parts),
            'work' => $this->get_dict_data(2, $obj->work_local),
            'bnum' => $this->bolt_num,
            'torque' => $this->torque
        ];
        $content['data'] = $data;
        $content['type'] = 'WorkRecord';
        return  $content;
    }
}
