<?php

namespace catchAdmin\worklocation\model;

use catchAdmin\api\Listen;
use catchAdmin\hydraulic\model\DeviceMold;
use catchAdmin\hydraulic\model\MaintenanceMapper as ModelMaintenancemapper;
use catchAdmin\permissions\model\DataRangScopeTrait;
use catchAdmin\permissions\model\Users;
use catchAdmin\wind\model\Fan;
use catchAdmin\wind\model\Wind;
use catcher\base\CatchModel as Model;


class Workplan extends Model
{
    use Listen;
    use DataRangScopeTrait;
    // 表名
    public $name = 'work_plan';
    // 数据库字段映射
    public $field = array(
        'id',
        // 风场id
        'wind_id',
        // 风机id
        'fan_id',
        // 工作位置
        'work_sign',
        // 部件类型
        'parts_sign',
        // 螺栓型号
        'boit_type_sign',
        // 计划名称
        'plan_name',
        // 详情
        'info',
        // 状态  1 启用，-1 失效
        'status',
        // 创建人ID
        'creator_id',
        // 创建时间
        'created_at',
        // 更新时间
        'updated_at',
        // 软删除
        'deleted_at',
    );
    /**
     * 监听转换
     */
    public function addContent(&$obj)
    {
        $data = null;
        $content = null;
        $data = [
            'id' => $obj->id,
            'pnum' => $obj->id,
            'wnum' => Wind::where('id', $obj->wind_id)->value('number'),
            'wname' => Wind::where('id', $obj->wind_id)->value('name'),
            'fnum' => Fan::where('id', $obj->wind_id)->value('number'),
            'fmode' => $obj->id,
            'work' => $obj->work_sign,
            'bm' => $obj->id,
            'bn' => $obj->id,
            'tm' => $obj->id,
            'bias' => $obj->id,
            'lt' => $obj->id,
            'torque' => $obj->id

        ];
        $content['data'] = $data;
        $content['type'] = 'WorkPlan';
        return  $content;
    }
    public function getList()
    {
        return $this->dataRange()
            ->catchSearch()
            ->append(['wind_name', 'fan_number', 'work_sign_name', 'parts_sign_name', 'boit_type_sign_name', 'status_name', 'creat_name', 'fan_model'])
            ->field('*')
            ->catchOrder()
            ->creator()
            ->paginate();
    }
    //获取风场名称
    public function getWindNameAttr()
    {
        $wind_id = $this->wind_id;
        $name =  Wind::where('id', $wind_id)->value('name');
        return $name;
    }
    //获取风机机位号
    public function getFanNumberAttr()
    {
        $fan_id = $this->fan_id;
        $number =  Fan::where('id', $fan_id)->value('number');
        return $number;
    }
    //获取工作位置
    public function getWorkSignNameAttr()
    {

        $name =  ModelMaintenancemapper::where('device_type', 2)->where('value', $this->work_sign)->value('name');
        return $name;
    }
    //获取部件
    public function getPartsSignNameAttr()
    {
        $name =  ModelMaintenancemapper::where('device_type', 1)->where('value', $this->parts_sign)->value('name');
        return $name;
    }
    //获取螺栓型号
    public function getBoitTypeSignNameAttr()
    {
        $name =  ModelMaintenancemapper::where('device_type', 4)->where('value', $this->boit_type_sign)->value('name');
        return $name;
    }
    public function getCreatNameAttr()
    {
        $name = null;
        $name =  Users::where('id', $this->creator_id)->value('realname');
        return $name;
    }
    //获取风机的型号id
    public function getFanModelAttr()
    {
        $fan_id = $this->fan_id;
        $fanModel =  Fan::where('id', $fan_id)->value('fan_model');
        return $fanModel;
    }
    public function searchPlanNameAttr($query, $value, $data)
    {
        return $query->where('plan_name', 'like', '%' . $value . '%');
    }
}
